@@ -141,6 +141,16 @@ static void test_quote(void) {
     free(out);
 }
 
+static void test_concat(void) {
+    const char *s = "2024:11";
+    char *out = sc_str_concat("my-prefix:", s);
+
+    // contains the concat
+    assert(!strcmp("my-prefix:2024:11", out));
+
+    free(out);
+}
+
 static void test_utf8_truncate(void) {
     const char *s = "aÉbÔc";
     assert(strlen(s) == 7); // É and Ô are 2 bytes-wide
@@ -269,21 +279,25 @@ static void test_parse_integer_with_suffix(void) {
 
     char buf[32];
 
-    sprintf(buf, "%ldk", LONG_MAX / 2000);
+    int r = snprintf(buf, sizeof(buf), "%ldk", LONG_MAX / 2000);
+    assert(r >= 0 && (size_t) r < sizeof(buf));
     ok = sc_str_parse_integer_with_suffix(buf, &value);
     assert(ok);
     assert(value == LONG_MAX / 2000 * 1000);
 
-    sprintf(buf, "%ldm", LONG_MAX / 2000);
+    r = snprintf(buf, sizeof(buf), "%ldm", LONG_MAX / 2000);
+    assert(r >= 0 && (size_t) r < sizeof(buf));
     ok = sc_str_parse_integer_with_suffix(buf, &value);
     assert(!ok);
 
-    sprintf(buf, "%ldk", LONG_MIN / 2000);
+    r = snprintf(buf, sizeof(buf), "%ldk", LONG_MIN / 2000);
+    assert(r >= 0 && (size_t) r < sizeof(buf));
     ok = sc_str_parse_integer_with_suffix(buf, &value);
     assert(ok);
     assert(value == LONG_MIN / 2000 * 1000);
 
-    sprintf(buf, "%ldm", LONG_MIN / 2000);
+    r = snprintf(buf, sizeof(buf), "%ldm", LONG_MIN / 2000);
+    assert(r >= 0 && (size_t) r < sizeof(buf));
     ok = sc_str_parse_integer_with_suffix(buf, &value);
     assert(!ok);
 }
@@ -358,7 +372,7 @@ static void test_index_of_column(void) {
     assert(sc_str_index_of_column("  a bc  d", 1, " ") == 2);
 }
 
-static void test_remove_trailing_cr() {
+static void test_remove_trailing_cr(void) {
     char s[] = "abc\r";
     sc_str_remove_trailing_cr(s, sizeof(s) - 1);
     assert(!strcmp(s, "abc"));
@@ -385,6 +399,7 @@ int main(int argc, char *argv[]) {
     test_join_truncated_before_sep();
     test_join_truncated_after_sep();
     test_quote();
+    test_concat();
     test_utf8_truncate();
     test_parse_integer();
     test_parse_integers();
